<?php

/**
 * education-monal functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package education-monal
 */

$education_theme_ob = wp_get_theme();
$education_ver      = $education_theme_ob->get('Version');
define('EDUCATION_VERSION', $education_ver);

if (!function_exists('monal_education_setup')) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function monal_education_setup()
	{
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on education-monal, use a find and replace
		 * to change 'education-monal' to the name of your theme in all the template files.
		 */
		load_theme_textdomain('education-monal', get_template_directory() . '/languages');

		// Add default posts and comments RSS feed links to head.
		add_theme_support('automatic-feed-links');

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support('title-tag');

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support('post-thumbnails');

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'menu-1' => esc_html__('Primary', 'education-monal'),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'monal_education_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);


		add_theme_support("wp-block-styles");
		add_theme_support("align-wide");
		add_theme_support("responsive-embeds");
		add_theme_support('register_block_pattern');
		add_theme_support('register_block_style');


		// Add theme support for selective refresh for widgets.
		add_theme_support('customize-selective-refresh-widgets');



		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 250,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
	}
endif;
add_action('after_setup_theme', 'monal_education_setup');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function monal_education_content_width()
{
	$GLOBALS['content_width'] = apply_filters('monal_education_content_width', 640);
}
add_action('after_setup_theme', 'monal_education_content_width', 0);

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function monal_education_widgets_init()
{
	register_sidebar(
		array(
			'name'          => esc_html__('Sidebar', 'education-monal'),
			'id'            => 'sidebar-1',
			'description'   => esc_html__('Add widgets here.', 'education-monal'),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__('Homepage Body', 'education-monal'),
			'id'            => 'homepage-1',
			'description'   => esc_html__('The homepage widgets goes here.', 'education-monal'),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title"><span class="title">',
			'after_title'   => '</span></h2>',
		)
	);

	register_sidebar(array(
		'name'          => esc_html__('Footer 1', 'education-monal'),
		'id'            => 'footer-1',
		'description'   => esc_html__('Add widgets here.', 'education-monal'),
		'before_widget' => '<section id="%1$s" class="widget %2$s footer-widget">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="footer-widget-title">',
		'after_title'   => '</h2>',
	));

	register_sidebar(array(
		'name'          => esc_html__('Footer 2', 'education-monal'),
		'id'            => 'footer-2',
		'description'   => esc_html__('Add widgets here.', 'education-monal'),
		'before_widget' => '<section id="%1$s" class="widget %2$s footer-widget">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="footer-widget-title">',
		'after_title'   => '</h2>',
	));
	register_sidebar(array(
		'name'          => esc_html__('Footer 3', 'education-monal'),
		'id'            => 'footer-3',
		'description'   => esc_html__('Add widgets here.', 'education-monal'),
		'before_widget' => '<section id="%1$s" class="widget %2$s footer-widget">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="footer-widget-title">',
		'after_title'   => '</h2>',
	));
	register_sidebar(array(
		'name'          => esc_html__('Footer 4', 'education-monal'),
		'id'            => 'footer-4',
		'description'   => esc_html__('Add widgets here.', 'education-monal'),
		'before_widget' => '<section id="%1$s" class="widget %2$s footer-widget">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="footer-widget-title">',
		'after_title'   => '</h2>',
	));
}
add_action('widgets_init', 'monal_education_widgets_init');

/**
 * Enqueue scripts and styles.
 */
function monal_education_scripts()
{
	wp_enqueue_style('education-monal-style', get_stylesheet_uri(), array(), EDUCATION_VERSION);
	wp_enqueue_style('education-monal-style-custom', get_template_directory_uri() . '/css/styles.css', array(), EDUCATION_VERSION);

	wp_enqueue_style('education-monal-font-style', 'https://fonts.googleapis.com/css2?family=Rubik&display=swap');
	wp_enqueue_style('education-monal-font-awesome', get_template_directory_uri() . '/css/bootstrap-icons.css', array(), EDUCATION_VERSION);

	wp_style_add_data('education-monal-style', 'rtl', 'replace');

	wp_enqueue_script('education-monal-navigation', get_template_directory_uri() . '/js/navigation.js', array(), EDUCATION_VERSION, true);

	wp_enqueue_script('education-monal-glide-js', get_template_directory_uri() . '/js/glide.min.js');

	wp_enqueue_script('education-monal-script-normal', get_template_directory_uri() . '/js/app.js',  array(), EDUCATION_VERSION, true);

	if (is_singular() && comments_open() && get_option('thread_comments')) {
		wp_enqueue_script('comment-reply');
	}
}
add_action('wp_enqueue_scripts', 'monal_education_scripts');

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if (defined('JETPACK__VERSION')) {
	require get_template_directory() . '/inc/jetpack.php';
}

/// The Breacdcrumb
if (!function_exists('monal_education_breadcrumb')) :
	function monal_education_breadcrumb()
	{
		if (!is_home()) {
			echo '<div class="breadcrumb"><a class="breadcrumb-link" href="';
			echo esc_url(home_url());
			echo '">';
			echo esc_html__('Home', 'education-monal');
			echo "</a> ";
			if (is_category() || is_single()) {
				if (is_single()) {
					the_category(' ');
					echo '<span class="current-link">';
					echo the_title();
					echo '</span>';
				}
				if (is_category()) {
					echo '<span class="current-link">';
					the_category(' ');
					echo '</span>';
				}
			} elseif (is_page()) {
				echo '<span class="current-link">';
				echo the_title();
				echo '</span>';
			} elseif (is_author()) {
				echo '<span class="current-link">';
				the_author();
				echo '</span>';
			} elseif (is_tag()) {
				echo '<span class="current-link">';
				echo esc_html__('Tag', 'education-monal');
				echo '</span>';
			}
			echo "</div>";
		}
	}
endif;


/**
 * Custom Widgets
 */
add_filter('widget_text', 'do_shortcode');


require_once dirname(__FILE__) . '/inc/custom_widgets/widget_blogs.php';
require_once dirname(__FILE__) . '/inc/custom_widgets/widget_courses.php';
require_once dirname(__FILE__) . '/inc/custom_widgets/widget_recent.php';
require_once dirname(__FILE__) . '/inc/custom_widgets/widget_contact.php';
require_once dirname(__FILE__) . '/inc/custom_widgets/widget_news_notice.php';
require_once dirname(__FILE__) . '/inc/custom_widgets/widget_footer_information.php';
require_once dirname(__FILE__) . '/inc/custom_widgets/widget_about.php';