<?php
// Register and load the widget
function monal_education_widget_about()
{
    register_widget('monal_education_about_widget');
}

add_action('widgets_init', 'monal_education_widget_about');

class monal_education_about_widget extends WP_Widget
{
    function scripts()
    {
        wp_enqueue_script('media-upload');
        wp_enqueue_media();
        wp_enqueue_script('our_admin', get_template_directory_uri() . '/js/our_admin.js', array('jquery'));
        wp_localize_script(
            'our_admin',
            'select_lang',
            array(
                'lang' => __('Select or upload image', 'education-monal'),
                'select_trans' => __('Select image', 'education-monal')
            )
        );
    }
    function __construct()
    {
        // Add Widget scripts

        add_action('admin_enqueue_scripts', array($this, 'scripts'));
        parent::__construct(
            'monal_education_about_widget',
            __('Education About Widget', 'education-monal'),
            array('description' => __('Education About Widget', 'education-monal'))
        );
    }

    // Creating widget front-end
    public function widget($args, $instance)
    {
        $wblog_title = (!empty($instance['wblog_title'])) ? $instance['wblog_title'] : esc_html__('Welcome To International College', 'education-monal');
        $wblog_subtitle = (!empty($instance['wblog_subtitle'])) ? $instance['wblog_subtitle'] :
            esc_html__('International College is a promising institution, which was founded by an enthusiastic group of academicals with the cherished goal of producing high quality manpower in the country & committed to provide excellent educational opportunity.
        We are committed to instill knowledge, skill, responsibility, discipline and commitment, the five pillars of success. It will be possible only through hard, concerted and dedicated efforts of all; students, teachers, guardians and parents, management and the community.
        This Institute proposes to carryout activities in the area of academics & technology. However, at the moment, It is running three-year Diploma Engineering programmes affiliated with the Council For Technical education & Vocational Training (CTEVT)', 'education-monal');

        $wblog_button = (!empty($instance['wblog_button'])) ? $instance['wblog_button'] : esc_html__('Read More', 'education-monal');
        $wblog_button_url = (!empty($instance['wblog_button_url'])) ? $instance['wblog_button_url'] : '';
        $wblog_image = !empty($instance['wblog_image']) ? $instance['wblog_image'] : '';

        echo $args['before_widget'];
?>

<section class="introduction section-padding bg-white">
    <div class="container">
        <div class="intro-grid edu-grid-box edu-grid-2 edu-md-grid-1">
            <div class="intro-info">
                <?php if ($wblog_title) : ?>
                <h2> <?php echo esc_html($wblog_title); ?> </h2>
                <?php endif; ?>

                <?php
                        if ($wblog_subtitle) : ?>
                <p><?php echo nl2br(esc_html($wblog_subtitle)); ?></p>
                <?php endif; ?>

                <?php if ($wblog_button) : ?>
                <a class="read-more-btn" href="<?php esc_url($wblog_button_url) ?>">
                    <?php echo esc_html($wblog_button); ?>
                </a>
                <?php endif; ?>


            </div>
            <div class="intro-image">
                <?php if ($wblog_image) : ?>
                <img src="<?php echo esc_url($wblog_image) ?>" alt="">
                <?php endif; ?>
            </div>
        </div>
    </div>

</section>
<?php
        echo $args['after_widget'];
    }

    // Widget Backend 
    public function form($instance)
    {
        $wblog_title = (!empty($instance['wblog_title'])) ? $instance['wblog_title'] : esc_html__('Welcome To International College', 'education-monal');
        $wblog_subtitle = (!empty($instance['wblog_subtitle'])) ? $instance['wblog_subtitle'] :
            esc_html__('
        International College is a promising institution, which was founded by an enthusiastic group of academicals with the cherished goal of producing high quality manpower in the country & committed to provide excellent educational opportunity.
        We are committed to instill knowledge, skill, responsibility, discipline and commitment, the five pillars of success. It will be possible only through hard, concerted and dedicated efforts of all; students, teachers, guardians and parents, management and the community.
        This Institute proposes to carryout activities in the area of academics & technology. However, at the moment, It is running three-year Diploma Engineering programmes affiliated with the Council For Technical education & Vocational Training (CTEVT)
        ', 'education-monal');
        $wblog_button = (!empty($instance['wblog_button'])) ? $instance['wblog_button'] : esc_html__('Read More', 'education-monal');
        $wblog_button_url = (!empty($instance['wblog_button_url'])) ? $instance['wblog_button_url'] : '';
        $wblog_image = !empty($instance['wblog_image']) ? $instance['wblog_image'] : '';

    ?>

<p>
    <label
        for="<?php echo $this->get_field_id('wblog_title'); ?>"><?php esc_html_e('Title', 'education-monal'); ?></label>
    <input class="widefat" id="<?php echo $this->get_field_id('wblog_title'); ?>"
        name="<?php echo $this->get_field_name('wblog_title'); ?>" type="text"
        value="<?php echo esc_attr($wblog_title); ?>" />
</p>
<p>
    <label for="<?php echo $this->get_field_id('wblog_image'); ?>"><?php _e('Image:', 'education-monal'); ?></label>
    <input class="widefat" id="<?php echo $this->get_field_id('wblog_image'); ?>"
        name="<?php echo $this->get_field_name('wblog_image'); ?>" type="url"
        value="<?php echo esc_url($wblog_image); ?>" />
    <button
        class="upload_image_button button button-primary"><?php esc_html_e('Upload Image', 'education-monal') ?></button>
    <img src="" alt="" id="previewimg" style="width:100%">
</p>
<p>
    <label
        for="<?php echo $this->get_field_id('wblog_subtitle'); ?>"><?php esc_html_e('Content', 'education-monal'); ?></label>
    <textarea class="widefat" name="<?php echo $this->get_field_name('wblog_subtitle'); ?>"
        id="<?php echo $this->get_field_id('wblog_subtitle'); ?>" cols="30" rows="10">
        <?php echo esc_attr($wblog_subtitle); ?>
        </textarea>
</p>
<p>
    <label
        for="<?php echo $this->get_field_id('wblog_button'); ?>"><?php esc_html_e('Button Text', 'education-monal'); ?></label>
    <input class="widefat" id="<?php echo $this->get_field_id('wblog_button'); ?>"
        name="<?php echo $this->get_field_name('wblog_button'); ?>" type="text"
        value="<?php echo esc_attr($wblog_button); ?>" />
</p>

<p>
    <label
        for="<?php echo $this->get_field_id('wblog_button_url'); ?>"><?php esc_html_e('Button Url', 'education-monal'); ?></label>
    <input class="widefat" id="<?php echo $this->get_field_id('wblog_button_url'); ?>"
        name="<?php echo $this->get_field_name('wblog_button_url'); ?>" type="url"
        value="<?php echo esc_attr($wblog_button_url); ?>" />
</p>

<?php
    }
    // Updating widget replacing old instances with new
    public function update($new_instance, $old_instance)
    {
        $instance = array();
        $instance['wblog_title'] = (!empty($new_instance['wblog_title'])) ? sanitize_text_field($new_instance['wblog_title']) : '';
        $instance['wblog_subtitle'] = (!empty($new_instance['wblog_subtitle'])) ? sanitize_textarea_field($new_instance['wblog_subtitle']) : '';
        $instance['wblog_button'] = (!empty($new_instance['wblog_button'])) ? sanitize_text_field($new_instance['wblog_button']) : '';
        $instance['wblog_image'] = (!empty($new_instance['wblog_image'])) ? esc_url($new_instance['wblog_image']) : '';
        return $instance;
    }
}


?>