<?php
// Register and load the widget
function monal_education_widget_blog()
{
    register_widget('monal_education_blog_widget');
}
add_action('widgets_init', 'monal_education_widget_blog');

class monal_education_blog_widget extends WP_Widget
{

    function __construct()
    {
        parent::__construct(
            'monal_education_blog_widget',
            __('Education Blog Lists', 'education-monal'),
            array('description' => __('Education Blog Lists', 'education-monal'))
        );
    }

    public function widget($args, $instance)
    {
        $wblog_category = (!empty($instance['wblog_category'])) ? $instance['wblog_category'] : '';
        $wblog_post_toshow = (!empty($instance['wblog_post_toshow'])) ? $instance['wblog_post_toshow'] : esc_html__('4', 'education-monal');
        $wblog_order = (!empty($instance['wblog_order'])) ? $instance['wblog_order'] : esc_html__('DESC', 'education-monal');
        $wblog_title = (!empty($instance['wblog_title'])) ? $instance['wblog_title'] : esc_html__('Blogs', 'education-monal');
        $wblog_columns = (!empty($instance['wblog_columns'])) ? $instance['wblog_columns'] : esc_html__('4', 'education-monal');
        echo $args['before_widget'];
?>

<section class="section-padding bg-white ">
    <div class="container">
        <?php if ($wblog_title) : ?>
        <div class="view-heading">
            <h2> <?php echo esc_html($wblog_title); ?> </h2>
            <a href="<?php echo esc_url(home_url() . '/category/' . $wblog_category) ?>"><span>
                    <?php echo esc_html('View All', 'education-monal') ?> <i class="bi bi-chevron-right"></i>
                </span></a>
        </div>
        <?php endif; ?>
        <div class="howbook-grid-box edu-grid-box edu-md-grid-2 edu-grid-<?php echo esc_attr($wblog_columns) ?> ">
            <?php
                    $q_args = array(
                        'post_type' => 'post',
                        'posts_per_page' => esc_attr(absint($wblog_post_toshow)),
                        'order_by' => 'date',
                        'post_status' => 'publish',
                        'order' => esc_attr($wblog_order),
                        'category_name' => esc_attr($wblog_category),
                    );
                    $bio = new WP_Query($q_args);
                    if ($bio->have_posts()) {
                        while ($bio->have_posts()) {
                            $bio->the_post();
                    ?>
            <div class="single-grid">
                <div class="card-box">
                    <?php
                                    $categories = get_the_category();
                                    if (!empty($categories)) {
                                    ?>
                    <a href="<?php echo esc_url(get_category_link($categories[0]->term_id)); ?>" class="card-category">
                        <?php
                                        echo esc_html($categories[0]->name);
                                    }
                                        ?>
                    </a>

                    <a href="<?php the_permalink() ?>" class="image-section">
                        <?php if (get_the_post_thumbnail_url()) {
                                                the_post_thumbnail('medium');
                                            } ?>
                    </a>
                    <div class="desc-section">
                        <div class="content-author">
                            <span><i class="bi bi-person-fill"></i>
                                <?php echo get_the_author() . ', ' .  get_the_date() ?></span>
                        </div>
                        <h3> <?php echo get_the_title() ?> </h3>
                    </div>
                </div>
            </div>
            <?php

                        }
                    }
                    wp_reset_postdata();
                    ?>

        </div>
    </div>
</section>
<?php
        echo $args['after_widget'];
    }

    // Widget Backend 
    public function form($instance)
    {

        $wblog_category = (!empty($instance['wblog_category'])) ? $instance['wblog_category'] : '';
        $wblog_order = (!empty($instance['wblog_order'])) ? $instance['wblog_order'] : esc_html__('DESC', 'education-monal');
        $wblog_post_toshow = (!empty($instance['wblog_post_toshow'])) ? $instance['wblog_post_toshow'] : esc_html__('4', 'education-monal');
        $wblog_title = (!empty($instance['wblog_title'])) ? $instance['wblog_title'] : esc_html__('Blogs', 'education-monal');
        $wblog_columns = (!empty($instance['wblog_columns'])) ? $instance['wblog_columns'] : esc_html__('4', 'education-monal');
    ?>

<p>
    <label
        for="<?php echo $this->get_field_id('wblog_title'); ?>"><?php esc_html_e('The Title of the Widget', 'education-monal'); ?></label>
    <input class="widefat" id="<?php echo $this->get_field_id('wblog_title'); ?>"
        name="<?php echo $this->get_field_name('wblog_title'); ?>" type="text"
        value="<?php echo esc_attr($wblog_title); ?>" />
</p>
<p>
    <label
        for="<?php echo $this->get_field_id('wblog_post_toshow'); ?>"><?php esc_html_e('Number of posts to show', 'education-monal'); ?></label>
    <input class="widefat" id="<?php echo $this->get_field_id('wblog_post_toshow'); ?>"
        name="<?php echo $this->get_field_name('wblog_post_toshow'); ?>" type="number"
        value="<?php echo esc_attr($wblog_post_toshow); ?>" />
</p>
<p>
    <label
        for="<?php echo $this->get_field_id('wblog_order'); ?>"><?php esc_html_e('Ordering: Either Ascending or Desending order', 'education-monal'); ?></label>
    <select class="widefat" id="<?php echo $this->get_field_id('wblog_order'); ?>"
        name="<?php echo $this->get_field_name('wblog_order'); ?>" value="<?php echo esc_attr($wblog_order); ?>">
        <option value="ASC" <?php echo ($wblog_order == 'ASC') ? 'selected' : ''; ?>>
            <?php esc_html_e('Ascending order', 'education-monal'); ?> </option>
        <option value="DESC" <?php echo ($wblog_order == 'DESC') ? 'selected' : ''; ?>>
            <?php esc_html_e('Descending order', 'education-monal'); ?> </option>
    </select>
</p>
<p>
    <label
        for="<?php echo $this->get_field_id('wblog_columns'); ?>"><?php esc_html_e('Number of columns', 'education-monal'); ?></label>
    <select class="widefat" id="<?php echo $this->get_field_id('wblog_columns'); ?>"
        name="<?php echo $this->get_field_name('wblog_columns'); ?>" value="<?php echo esc_attr($wblog_columns); ?>">
        <option value="2" <?php echo ($wblog_columns == '2') ? 'selected' : ''; ?>>
            <?php esc_html_e('2', 'education-monal'); ?> </option>
        <option value="3" <?php echo ($wblog_columns == '3') ? 'selected' : ''; ?>>
            <?php esc_html_e('3', 'education-monal'); ?> </option>
        <option value="4" <?php echo ($wblog_columns == '4') ? 'selected' : ''; ?>>
            <?php esc_html_e('4', 'education-monal'); ?> </option>
    </select>
</p>
<p>
    <label
        for="<?php echo $this->get_field_id('wblog_category'); ?>"><?php esc_html_e('Select the category:', 'education-monal'); ?></label>
    <select class="widefat" id="<?php echo $this->get_field_id('wblog_category'); ?>"
        name="<?php echo $this->get_field_name('wblog_category'); ?>">

        <?php
                $ag = array(
                    'post_type' => 'post',
                );
                $all_categories = get_categories($ag);
                foreach ($all_categories as $cat) {
                ?>
        <option value="<?php echo $cat->slug; ?>" <?php echo ($wblog_category == $cat->slug) ? 'selected' : ''; ?>>
            <?php echo $cat->name; ?></option>
        <?php
                }
                ?>
    </select>
</p>

<?php
    }
    // Updating widget replacing old instances with new
    public function update($new_instance, $old_instance)
    {
        $instance = array();
        $instance['wblog_category'] = (!empty($new_instance['wblog_category'])) ? sanitize_text_field($new_instance['wblog_category']) : '';
        $instance['wblog_order'] = (!empty($new_instance['wblog_order'])) ? sanitize_text_field($new_instance['wblog_order']) : '';
        $instance['wblog_columns'] = (!empty($new_instance['wblog_columns'])) ? absint($new_instance['wblog_columns']) : '';
        $instance['wblog_title'] = (!empty($new_instance['wblog_title'])) ? sanitize_text_field($new_instance['wblog_title']) : '';
        $instance['wblog_post_toshow'] = (!empty($new_instance['wblog_post_toshow'])) ? intval($new_instance['wblog_post_toshow']) : '';

        return $instance;
    }
}
?>