<?php

/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package education-monal
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function monal_education_body_classes($classes)
{
	// Adds a class of hfeed to non-singular pages.
	if (!is_singular()) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if (!is_active_sidebar('sidebar-1')) {
		$classes[] = 'no-sidebar';
	}

	return $classes;
}
add_filter('body_class', 'monal_education_body_classes');

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function monal_education_pingback_header()
{
	if (is_singular() && pings_open()) {
		printf('<link rel="pingback" href="%s">', esc_url(get_bloginfo('pingback_url')));
	}
}
add_action('wp_head', 'monal_education_pingback_header');


function monal_education_topbar()
{
?>
<div class="top-bar">
    <div class="container edu-top-hold">
        <div class="edu-info">
            <?php if (get_theme_mod('topbar_phone', '+21-323-435')) {
					echo '<i class="bi bi-telephone-fill"></i><span>' . esc_html(get_theme_mod('topbar_phone', '+21-323-435')) . '</span>';
				} ?>
            <?php if (get_theme_mod('topbar_location', 'Rato Bangla, Kathmandu')) {
					echo '<i class="bi bi-geo-alt-fill"></i><span>' . esc_html(get_theme_mod('topbar_location', 'Rato Bangla, Kathmandu')) . '</span>';
				} ?>
            <?php if (get_theme_mod('topbar_email', 'john.doe@gmail.com')) {
					echo '<i class="bi bi-envelope"></i><span>' . esc_html(get_theme_mod('topbar_email', 'john.doe@gmail.com')) . '</span>';
				} ?>
        </div>
        <div class="edu-social">
            <?php if (get_theme_mod('topbar_facebook', 'https://facebook.com')) {
					echo '<a href="' . esc_url(get_theme_mod('topbar_facebook', 'https://facebook.com')) . '"><i class="bi bi-facebook"></i></a>';
				} ?>
            <?php if (get_theme_mod('topbar_twiiter', 'https://twitter.com')) {
					echo '<a href="' . esc_url(get_theme_mod('topbar_twitter', 'https://twitter.com')) . '"><i class="bi bi-twitter"></i></a>';
				} ?>
            <?php if (get_theme_mod('topbar_instagram', 'https://instagram.com')) {
					echo '<a href="' . esc_url(get_theme_mod('topbar_instagram', 'https://instagram.com')) . '"><i class="bi bi-instagram"></i></a>';
				} ?>
        </div>
    </div>
</div>
<?php
}

function monal_education_mainnav()
{
	if (get_theme_mod('navbar_select', 'box') == 'fullwidth') {
		$container = "container-fluid";
	} else {
		$container = "container";
	}
?>
<div class="<?php echo esc_attr($container); ?>">
    <div class="navbar ss-nav">
        <div class="navbar-logo">
            <?php
				$mobilemargin = "";
				if (get_theme_mod('search_visibility', '1') == 1) {
					$mobilemargin = "btn-margin";
				} ?>

            <div class="logo-flex">

                <?php
					if (has_custom_logo()) :
						the_custom_logo();
					endif;
					?>
                <div class="site-title-wrapper">
                    <?php
						if (get_theme_mod('display_title_tagline', true)) {
							if (is_front_page() || is_home()) : ?>

                    <h1 class="site-title"><a href="<?php echo esc_url(home_url('/')); ?>"
                            rel="home"><?php bloginfo('name'); ?></a></h1>

                    <?php else : ?>
                    <p class="site-title"><a href="<?php echo esc_url(home_url('/')); ?>"
                            rel="home"><?php bloginfo('name'); ?></a></p>
                    <?php
							endif;
							$description = get_bloginfo('description', 'display');
							if ($description || is_customize_preview()) : ?>
                    <span class="site-description">
                        <?php echo esc_html($description); /* WPCS: xss ok. */ ?>
                    </span>

                    <?php
							endif;
						}
						?>
                </div>
            </div>
            <button class="hamburger <?php echo esc_attr($mobilemargin); ?>" id="ham-open"
                onclick="monal_education_openside()"> <i class="bi bi-filter-right"></i> </button>
        </div>

        <?php
			if (has_nav_menu('menu-1')) {
				wp_nav_menu(
					array(
						'theme_location' => 'menu-1',
						'menu_id'        => 'primary-menu',
						'menu_class'        => 'nav-menu',
						'container_class' => 'navbar-links'
					)
				);
			} else {
				wp_nav_menu(
					array(
						'theme_location' => 'menu-1',
						'menu_id'        => 'primary-menu',
						'menu_class' => 'navbar-links'
					)
				);
			}

			?>


        <?php if (get_theme_mod('search_visibility', '1') == 1) {
				$mobilemargin = "btn-margin"
			?>
        <button class="edu-search" id="search-open" onclick="monal_education_searchopen()">
            <i class="bi bi-search"></i>
        </button>

        <div class="search-glam" id="search-show" tabindex="-1">
            <div class="container">
                <div class="search-query">
                    <form method="get" class="search-form" action="<?php echo esc_url(home_url()); ?>">
                        <label>
                            <span
                                class="screen-reader-text"><?php esc_html_e('Search For: ', 'education-monal'); ?></span>
                            <input type="search" id="search-input" class="search-field"
                                placeholder="<?php echo esc_attr__('Search Here', 'education-monal') ?>" value=""
                                name="<?php echo esc_attr__('s', 'education-monal') ?>">
                        </label>
                    </form>
                    <button class="cross" onclick="monal_education_searchclose()">
                        <i class="bi bi-x-lg"></i>
                    </button>
                </div>
            </div>
        </div>
        <?php
			} ?>

        <div class="sidenavbar" id="sidenav">

            <button class="cross-btn" id="cross-now" onclick="monal_education_closeside()"> <i class="bi bi-x-lg"></i>
            </button>
            <?php
				if (has_nav_menu('menu-1')) {
					wp_nav_menu(
						array(
							'theme_location' => 'menu-1',
							'menu_id'        => 'side-menu',
							'menu_class'        => 'nav-menu',
							'container' => ''
						)
					);
				} else {
					wp_nav_menu(
						array(
							'theme_location' => 'menu-1',
							'menu_id'        => 'primary-menu',
							'container_class' => 'navbar-links'
						)
					);
				}
				?>
        </div>
    </div>
    <div id="background-dark" onclick="monal_education_closeside()">
    </div>
</div>
<?php
}


function monal_education_title_with_link($title, $category_name)
{
?>
<div class="view-heading">
    <?php
		if ($title) :
		?>
    <h2> <?php echo esc_html($title); ?> </h2>
    <?php endif;
		?>
    <a href="<?php echo esc_url(home_url() . '/category/' . $category_name . '') ?>">
        <span><?php echo esc_html('View All', 'education-monal') ?> <i class="bi bi-chevron-right"></i>
        </span>
    </a>

</div>
<?php
	return $title;
}

function single_item_blog($post_type, $post_per_page, $category_name)
{
	$q_args = array(
		'post_type' => $post_type,
		'posts_per_page' => $post_per_page,
		'order_by' => 'date',
		'post_status' => 'publish',
		'category_name' => $category_name,
	);
	$bio = new WP_Query($q_args);
	if ($bio->have_posts()) {

		if ($category_name == 'news') {
			while ($bio->have_posts()) {
				$bio->the_post();
	?>
<a href="<?php echo the_permalink() ?>" class="single-news">
    <div class="news-date">
        <div class="main-date">
            <?php echo get_the_date('j') ?>
        </div>
        <span> <?php echo get_the_date('M, Y') ?> </span>
    </div>
    <div class="news-info">
        <h3 class="news-heading"> <?php echo get_the_title() ?> </h3>
    </div>
</a>
<?php
			}
			wp_reset_postdata();
		} else if ($category_name == 'notice') {
			while ($bio->have_posts()) {
				$bio->the_post();
			?>
<a href="<?php echo the_permalink() ?>" class="single-notice">
    <div class="notice-date">
        <span class="main-date"> <?php echo get_the_date('j') ?></span> <br>
        <?php echo get_the_date('M') ?>
    </div>
    <div class="notice-info">
        <?php echo get_the_title() ?>
    </div>
</a>
<?php
			}
			wp_reset_postdata();
		} else if ($category_name == 'courses') {
			while ($bio->have_posts()) {
				$bio->the_post();
			?>

<a class="single-grid" href="<?php the_permalink() ?>">
    <div class="course-card-box">
        <div class="course-image-section">
            <?php if (get_the_post_thumbnail_url()) {
								the_post_thumbnail('medium');
							} ?>
        </div>
        <div class="course-desc-section">
            <h3> <?php echo get_the_title() ?> </h3>
            <p> <?php echo get_the_excerpt() ?></p>
        </div>
    </div>
</a>
<?php
			}
			wp_reset_postdata();
		}
	}
}