/* global wp, jQuery */
/**
 * File customizer.js.
 *
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

(function ($) {
	// Site title and description.
	wp.customize('blogname', function (value) {
		value.bind(function (to) {
			$('.site-title a').text(to);
		});
	});
	wp.customize('blogdescription', function (value) {
		value.bind(function (to) {
			$('.site-description').text(to);
		});
	});

	// Header text color.
	wp.customize('header_textcolor', function (value) {
		value.bind(function (to) {
			if ('blank' === to) {
				$('.site-title, .site-description').css({
					clip: 'rect(1px, 1px, 1px, 1px)',
					position: 'absolute',
					display: 'none'
				});
			} else {
				$('.site-title, .site-description').css({
					clip: 'auto',
					position: 'relative',
					display: 'block'
				});
				$('.site-title a, .site-description').css({
					color: to,
				});
			}
		});
	});

	// Hide Search Button
	wp.customize('search_visibility', function (value) {
		value.bind(function (to) {
			if (true === to) {
				$('.edu-search').css({
					display: 'block'
				});
				$('.hamburger').css({
					marginRight: '45px'
				});
			} else {
				$('.edu-search').css({
					display: 'none'
				});
				$('.hamburger').css({
					marginRight: '0px'
				});
			}
		});
	});

	// Top Bar Visibility
	wp.customize('topbar_visibility', function (value) {
		value.bind(function (to) {
			if (true === to) {
				$('.top-bar').css({
					display: 'block'
				});
			} else {
				$('.top-bar').css({
					display: 'none'
				});
			}
		});
	});

	// Hide Copyright Section
	wp.customize('copyright_display', function (value) {
		value.bind(function (to) {
			if ('hide' === to) {
				$('.copyright').css({
					display: 'none'
				});
			} else {
				$('.copyright').css({
					display: 'block'
				});
			}
		});
	});


	// Copyright Text
	wp.customize('copyright_text_footer', function (value) {
		value.bind(function (to) {
			$('.copyright p').text(to);
		});
	});


	// Navigation Colors 

	// Navbar Background
	wp.customize('header_background', function (value) {
		value.bind(function (to) {
			$('.nav-back').css({
				background: to,
			});
		});
	});

	// Navbar Text Color
	wp.customize('header_text_color', function (value) {
		value.bind(function (to) {
			$('.navbar .navbar-links>ul>li a').css({
				color: to,
			});
			$('.edu-search').css({
				color: to,
			});
			$('.font-big').css({
				color: to,
			});
			$('.font-small').css({
				color: to,
			});
		});
	});

	// Navbar Text Hover
	wp.customize('header_hover_color', function (value) {
		value.bind(function (to) {
			$('.navbar .navbar-links>ul>li').hover(function () {
				$(this).css({
					background: to,
				});
			}, function () {
				$(this).removeAttr('style');
			});
		});
	});

	// Dropdown Bckground
	wp.customize('dropdown_background', function (value) {
		value.bind(function (to) {
			$('.navbar .navbar-links>ul>li .sub-menu>li').css({
				background: to,
			});
		});
	});

	// Dropdown Text
	wp.customize('dropdown_color', function (value) {
		value.bind(function (to) {
			$('.navbar .navbar-links>ul>li .sub-menu>li>a').css({
				color: to,
			});
		});
	});

	// Navbar Logo Width 
	wp.customize('logo_width', function (value) {
		value.bind(function (to) {
			$('.navbar .navbar-logo img').css({
				width: to + 'px',
			});
		});
	});

	// HEading Sizes 

	// Heading One 
	wp.customize('edu_heading_one_size', function (value) {
		value.bind(function (to) {
			$('.single-title').css({
				fontSize: to + 'px',
			});
		});
	});

	// Heading Two
	wp.customize('edu_heading_two_size', function (value) {
		value.bind(function (to) {
			$('.main-content h2').css({
				fontSize: to + 'px',
			});
		});
	});

	// Heading THree
	wp.customize('edu_heading_three_size', function (value) {
		value.bind(function (to) {
			$('.main-content h3').css({
				fontSize: to + 'px',
			});
		});
	});
	// Heading Four
	wp.customize('edu_heading_four_size', function (value) {
		value.bind(function (to) {
			$('.main-content h4').css({
				fontSize: to + 'px',
			});
		});
	});
	// Paragraph
	wp.customize('edu_paragraph_size', function (value) {
		value.bind(function (to) {
			$('.main-content p').css({
				fontSize: to + 'px',
			});
		});
	});

	// Meta Size 
	wp.customize('edu_meta_size', function (value) {
		value.bind(function (to) {
			$('.entry-meta').css({
				fontSize: to + 'px',
			});
		});
	});

	// Widget Title
	wp.customize('edu_widget_title_size', function (value) {
		value.bind(function (to) {
			$('.widget h2').css({
				fontSize: to + 'px',
			});
		});
	});

}(jQuery));
